@@ -6,7 +6,7 @@ use Carp qw( carp );
 use File::Basename qw( basename );
 
 # ABSTRACT: Interface for manipulating ar archives with libarchive
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 unless($^O eq 'MSWin32')
 {
@@ -211,7 +211,7 @@ Archive::Ar::Libarchive - Interface for manipulating ar archives with libarchive
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -235,18 +235,27 @@ version 0.05
 
 =head1 DESCRIPTION
 
-This module is a XS alternative to L<Archive::Ar> that uses libarchive to read and write ar BSD, GNU and common ar archives.
+This module is a XS alternative to L<Archive::Ar> that uses libarchive 
+to read and write ar BSD, GNU and common ar archives.
 
-There is no standard for the ar format.  Most modern archives are based on a common format with two extension variants, BSD and GNU.  Other
-esoteric variants (such as AIX (small), AIX (big) and Coherent) vary significantly from the common format and are not supported.  Debian's
+There is no standard for the ar format.  Most modern archives are based 
+on a common format with two extension variants, BSD and GNU.  Other 
+esoteric variants (such as AIX (small), AIX (big) and Coherent) vary 
+significantly from the common format and are not supported.  Debian's 
 package format (.deb files) use the common format.
 
-The interface attempts to be identical (with a couple of minor extensions) to L<Archive::Ar> and the documentation presented here is based on that module.
-The diagnostic messages issued on error mostly come directly from libarchive, so they will likely not match exactly what L<Archive::Ar> would produce,
-but it should issue a warning (when L<DEBUG|Archive::Ar::Libarchive#DEBUG> is turned on) under similar circumstances.
+The interface attempts to be identical (with a couple of minor 
+extensions) to L<Archive::Ar> and the documentation presented here is 
+based on that module. The diagnostic messages issued on error mostly 
+come directly from libarchive, so they will likely not match exactly 
+what L<Archive::Ar> would produce, but it should issue a warning (when 
+L<Archive::Ar::Libarchive#DEBUG> is turned on) under similar 
+circumstances.
 
-The main advantage of L<Archive::Ar> over this module is that it is written in pure perl, and thus does not require a compiler or libarchive.  The advantage of this module
-(at least as of this writing) is that it supports GNU and BSD extensions for longer member filenames.
+The main advantage of L<Archive::Ar> over this module is that it is 
+written in pure perl, and thus does not require a compiler or 
+libarchive.  The advantage of this module (at least as of this writing) 
+is that it supports GNU and BSD extensions for longer member filenames.
 
 =head1 METHODS
 
@@ -256,11 +265,15 @@ The main advantage of L<Archive::Ar> over this module is that it is written in p
  my $ar = Archive::Ar::Libarchive->new($filename);
  my $ar = Archive::Ar::Libarchive->new($fh, $debug);
 
-Returns a new L<Archive::AR::Libarchive> object.  Without a filename or glob, it returns an empty object.  If passed a filename as a scalar or a GLOB, it will attempt to populate from
-either of those sources.  If it fails, you will receive undef, instead of an object reference.
+Returns a new L<Archive::AR::Libarchive> object.  Without a filename or 
+glob, it returns an empty object.  If passed a filename as a scalar or a 
+GLOB, it will attempt to populate from either of those sources.  If it 
+fails, you will receive undef, instead of an object reference.
 
-This also can take a second optional debugging parameter.  This acts exactly as if L<DEBUG|Archive::Ar::Libarchive#DEBUG> is called on the object before it is returned.  If you have a L<new|Archive::Ar::Libarchive#new> that keeps failing, this
-should help.
+This also can take a second optional debugging parameter.  This acts 
+exactly as if L<Archive::Ar::Libarchive#DEBUG> is called on the object 
+before it is returned.  If you have a L<Archive::Ar::Libarchive#new> 
+that keeps failing, this should help.
 
 =head2 read
 
@@ -276,10 +289,11 @@ Returns the number of bytes read, undef on failure.
 
  my $br = $ar->read_memory($data);
 
-This reads information from the first parameter, and attempts to parse and treat
-it like an ar archive. Like L<read|Archive::Ar::Libarchive#read>, it will wipe out whatever you have in the
-object and replace it with the contents of the new archive, even if it fails.
-Returns the number of bytes read (processed) if successful, undef otherwise.
+This reads information from the first parameter, and attempts to parse 
+and treat it like an ar archive. Like L<Archive::Ar::Libarchive#read>, 
+it will wipe out whatever you have in the object and replace it with the 
+contents of the new archive, even if it fails. Returns the number of 
+bytes read (processed) if successful, undef otherwise.
 
 =head2 list_files
 
@@ -301,8 +315,9 @@ information is stripped off. Filenames longer than 16 characters are
 truncated when written to disk in the format, so keep that in mind
 when adding files.
 
-Due to the nature of the ar archive format, L<add_files|Archive::Ar::Libarchive#add_files> will store
-the uid, gid, mode, size, and creation date of the file as returned by
+Due to the nature of the ar archive format, 
+L<Archive::Ar::Libarchive#add_files> will store the uid, gid, mode, 
+size, and creation date of the file as returned by 
 L<stat|perlfunc#stat>.
 
 returns the number of files successfully added, or undef on failure.
@@ -311,9 +326,10 @@ returns the number of files successfully added, or undef on failure.
 
  my $size = $ar->add_data($filename, $data, $filedata);
 
-Takes an filename and a set of data to represent it. Unlike L<add_files|Archive::Ar::Libarchive#add_files>, L<add_data|Archive::Ar::Libarchive#add_data>
-is a virtual add, and does not require data on disk to be present. The
-data is a hash that looks like:
+Takes an filename and a set of data to represent it. Unlike 
+L<Archive::Ar::Libarchive#add_files>, 
+L<Archive::Ar::Libarchive#add_data> is a virtual add, and does not 
+require data on disk to be present. The data is a hash that looks like:
 
  $filedata = {
    uid  => $uid,   #defaults to zero
@@ -322,18 +338,19 @@ data is a hash that looks like:
    mode => $mode,  #defaults to 0100644;
  };
 
-You cannot add_data over another file however.  This returns the file length in
-bytes if it is successful, undef otherwise.
+You cannot add_data over another file however.  This returns the file 
+length in bytes if it is successful, undef otherwise.
 
 =head2 write
 
  my $content = $ar->write;
  my $size = $ar->write($filename);
 
-This method will return the data as an .ar archive, or will write to
-the filename present if specified. If given a filename, L<write|Archive::Ar::Libarchive#write> will
-return the length of the file written, in bytes, or undef on failure.
-If the filename already exists, it will overwrite that file.
+This method will return the data as an .ar archive, or will write to the 
+filename present if specified. If given a filename, 
+L<Archive::Ar::Libarchive#write> will return the length of the file 
+written, in bytes, or undef on failure. If the filename already exists, 
+it will overwrite that file.
 
 =head2 get_content
 
@@ -389,22 +406,23 @@ of files successfully removed from the archive.
 
  $ar->set_output_format_bsd;
 
-Sets the output format produced by L<write|Archive::Ar::Libarchive#write> to use BSD format.
-Note: this method is not available in l<Archive::Ar>.
+Sets the output format produced by L<Archive::Ar::Libarchive#write> to 
+use BSD format. Note: this method is not available in l<Archive::Ar>.
 
 =head2 set_output_format_svr4
 
  $ar->set_output_format_svr4;
 
-Sets the output format produced by L<write|Archive::Ar::Libarchive#write> to System VR4 format.
-Note: this method is not available in l<Archive::Ar>.
+Sets the output format produced by L<Archive::Ar::Libarchive#write> to 
+System VR4 format. Note: this method is not available in l<Archive::Ar>.
 
 =head2 DEBUG
 
  $ar->DEBUG;
  $ar->DEBUG(0);
 
-This method turns on debugging.  To Turn off pass a false value in as the argument.
+This method turns on debugging.  To Turn off pass a false value in as 
+the argument.
 
 =head1 SEE ALSO
 
